NoneBot.drivers.fastapi 模块 | NoneBot
Description: 跨平台 Python 异步 QQ 机器人框架

# # NoneBot.drivers.fastapi 模块

## # FastAPI 驱动适配

后端使用方法请参考: FastAPI 文档
(opens new window)

## # class `Config`

基类：`pydantic.env_settings.BaseSettings`

FastAPI 驱动框架设置，详情参考 FastAPI 文档

### # `fastapi_openapi_url`

- 类型

  `Optional[str]`

- 说明

  `openapi.json` 地址，默认为 `None` 即关闭

### # `fastapi_docs_url`

- 类型

  `Optional[str]`

- 说明

  `swagger` 地址，默认为 `None` 即关闭

### # `fastapi_redoc_url`

- 类型

  `Optional[str]`

- 说明

  `redoc` 地址，默认为 `None` 即关闭

### # `fastapi_reload_dirs`

- 类型

  `List[str]`

- 说明

  `debug` 模式下重载监控文件夹列表，默认为 uvicorn 默认值

## # class `Driver`

基类：`nonebot.drivers.Driver`

FastAPI 驱动框架

- 上报地址

  - `/{adapter name}/`: HTTP POST 上报

  - `/{adapter name}/http/`: HTTP POST 上报

  - `/{adapter name}/ws`: WebSocket 上报

  - `/{adapter name}/ws/`: WebSocket 上报

### # property `type`

驱动名称: `fastapi`

### # property `server_app`

`FastAPI APP` 对象

### # property `asgi`

`FastAPI APP` 对象

### # property `logger`

fastapi 使用的 logger

### # `on_startup(func)`

参考文档: Events
(opens new window)

### # `on_shutdown(func)`

参考文档: Events
(opens new window)

### # `run(host=None, port=None, *, app=None, **kwargs)`

使用 `uvicorn` 启动 FastAPI

Contents

- FastAPI 驱动适配
- class Config
  - fastapi_openapi_url
  - fastapi_docs_url
  - fastapi_redoc_url
  - fastapi_reload_dirs
- class Driver
  - property type
  - property server_app
  - property asgi
  - property logger
  - on_startup(func)
  - on_shutdown(func)
  - run(host=None, port=None, *, app=None, **kwargs)